@@ -86,7 +86,7 @@ static char status_path[512];
 static int status_count;
 static bool status_shown = false;
 
-static void status_cb(void * unused)
+static void status_cb()
 {
     auto mh = mutex.take();
 
@@ -118,7 +118,7 @@ static void status_update(const char * filename, int found)
     status_count = found;
 
     if (!status_timer.running())
-        status_timer.start(250, status_cb, nullptr);
+        status_timer.start(250, status_cb);
 }
 
 static void status_done_locked()
@@ -351,7 +351,9 @@ static void add_folder(const char * filename, Playlist::FilterFunc filter,
         if (error)
             AUDERR("%s: %s\n", (const char *)file, (const char *)error);
 
-        if (mode & VFS_IS_SYMLINK)
+        // to prevent infinite recursion, skip symlinks to folders
+        if ((mode & (VFS_IS_SYMLINK | VFS_IS_DIR)) ==
+            (VFS_IS_SYMLINK | VFS_IS_DIR))
             continue;
 
         if (mode & VFS_IS_REGULAR)
@@ -442,7 +444,7 @@ static void stop_thread_locked()
     }
 }
 
-static void add_finish(void * unused)
+static void add_finish()
 {
     auto mh = mutex.take();
 
@@ -532,7 +534,7 @@ static void add_worker()
         current_playlist = Playlist();
 
         if (!add_results.head())
-            queued_add.queue(add_finish, nullptr);
+            queued_add.queue(add_finish);
 
         add_results.append(result);
     }
