@@ -215,12 +215,14 @@ static void load_fallback_icons ()
         "document-open",
         "document-save",
         "edit-clear",
+        "edit-clear-all",
         "edit-copy",
         "edit-cut",
         "edit-delete",
         "edit-find",
         "edit-paste",
         "edit-select-all",
+        "edit-undo",
         "face-smile",
         "folder-remote",
         "folder",
