@@ -41,7 +41,7 @@ private:
     void update();
 
     const MenuItem & m_item;
-    SmartPtr<HookReceiver<MenuAction>> m_hook;
+    HookReceiver<MenuAction> m_hook{this, &MenuAction::update};
 };
 
 MenuAction::MenuAction(const MenuItem & item, const char * domain,
@@ -64,8 +64,7 @@ MenuAction::MenuAction(const MenuItem & item, const char * domain,
         QObject::connect(this, &QAction::toggled, this, &MenuAction::toggle);
 
         if (item.cfg.hook)
-            m_hook.capture(new HookReceiver<MenuAction>(item.cfg.hook, this,
-                                                        &MenuAction::update));
+            m_hook.connect(item.cfg.hook);
     }
     else if (item.func)
         QObject::connect(this, &QAction::triggered, item.func);
@@ -75,7 +74,7 @@ MenuAction::MenuAction(const MenuItem & item, const char * domain,
         setMenu(item.submenu());
 
 #ifndef Q_OS_MAC
-    if (item.text.icon && QIcon::hasThemeIcon(item.text.icon))
+    if (item.text.icon)
         setIcon(audqt::get_icon(item.text.icon));
 #endif
 
